==> okteta-0.25.0.tar.xz: okteta-0.25.0/libs/kasten/core/io/abstractmodelexporter.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2007-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "abstractmodelexporter.h"
#include "abstractmodelexporter_p.h"

namespace Kasten {

AbstractModelExporter::AbstractModelExporter(AbstractModelExporterPrivate* d)
    : d_ptr(d)
{
}

AbstractModelExporter::AbstractModelExporter(const QString& remoteTypeName, const QString& remoteMimeType)
    : d_ptr(new AbstractModelExporterPrivate(this, remoteTypeName, remoteMimeType))
{
}

AbstractModelExporter::~AbstractModelExporter()
{
    delete d_ptr;
}

QString AbstractModelExporter::remoteTypeName() const
{
    Q_D(const AbstractModelExporter);

    return d->remoteTypeName();
}

QString AbstractModelExporter::remoteMimeType() const
{
    Q_D(const AbstractModelExporter);

    return d->remoteMimeType();
}

}

==> okteta-0.26.1.tar.xz: okteta-0.26.1/libs/kasten/core/io/abstractmodelexporter.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2007-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "abstractmodelexporter.hpp"
#include "abstractmodelexporter_p.hpp"

namespace Kasten {

AbstractModelExporter::AbstractModelExporter(AbstractModelExporterPrivate* d)
    : d_ptr(d)
{
}

AbstractModelExporter::AbstractModelExporter(const QString& remoteTypeName, const QString& remoteMimeType)
    : d_ptr(new AbstractModelExporterPrivate(this, remoteTypeName, remoteMimeType))
{
}

AbstractModelExporter::~AbstractModelExporter() = default;

QString AbstractModelExporter::remoteTypeName() const
{
    Q_D(const AbstractModelExporter);

    return d->remoteTypeName();
}

QString AbstractModelExporter::remoteMimeType() const
{
    Q_D(const AbstractModelExporter);

    return d->remoteMimeType();
}

}
